==> GymBuddy-1.0.6.tar.gz: GymBuddy-1.0.6/GymBuddyApp/gymBuddyApp/urls.py <==
"""gymBuddyApp URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.contrib.auth import views as auth_views
from django.urls import path, include
from GymBuddyApp.users import views as user_views
#we do not need to import views from pages since pages already has a urls.py file


urlpatterns = [
    path('', include('GymBuddyApp.pages.urls')),
    path('admin/', admin.site.urls),
    path('login/', auth_views.LoginView.as_view(template_name='users/login.html'), name='login'),
    path('logout/', auth_views.LogoutView.as_view(template_name='users/logout.html'), name='logout'),
    path('profile/', user_views.profile, name='profile'),
    path('register/', user_views.register, name='register'),
    path('weight/', user_views.weight, name='weight'),
    path('macros/', user_views.macros, name='macros'),
    path('exercises/', user_views.exercises, name='exercises'),
    path('exercises/<int:active_exercises>', user_views.exercises, name='exercises'),
    path('meals/', user_views.meals, name='meals'),
    path('login/', user_views.login2, name='login')
]

==> GymBuddy-2.1.6.tar.gz: GymBuddy-2.1.6/GymBuddyApp/gymBuddyApp/urls.py <==
"""gymBuddyApp URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.contrib.auth import views as auth_views
from django.urls import path, include
from GymBuddyApp.users import views as user_views
#we do not need to import views from pages since pages already has a urls.py file


urlpatterns = [
    path('', include('GymBuddyApp.pages.urls')),
    path('admin/', admin.site.urls),
    path('login/', auth_views.LoginView.as_view(template_name='users/login.html'), name='login'),
    path('logout/', auth_views.LogoutView.as_view(template_name='users/logout.html'), name='logout'),
    path('profile/', user_views.profile, name='profile'),
    path('register/', user_views.register, name='register'),
    path('weight/', user_views.weight, name='weight'),
    path('macros/', user_views.macros, name='macros'),
    path('exercises/', user_views.exercises, name='exercises'),
    path('exercises/<int:active_exercises>', user_views.exercises, name='exercises'),
    path('meals/', user_views.meals, name='meals'),
    path('login/', user_views.login2, name='login'),
    path('password-reset/',
         auth_views.PasswordResetView.as_view(template_name='users/password_reset.html'),
         name='password_reset'),
    path('password-reset/done',
         auth_views.PasswordResetDoneView.as_view(template_name='users/password_reset_done.html'),
         name='password_reset_done'),
    path('password-reset-confirm/<uidb64>/<token>/',
         auth_views.PasswordResetConfirmView.as_view(template_name='users/password_reset_confirm.html'),
         name='password_reset_confirm'),
    path('password-reset-complete/',
         auth_views.PasswordResetCompleteView.as_view(template_name='users/password_reset_complete.html'),
         name='password_reset_complete')
]
